@@ -7,7 +7,7 @@ use PDF::API2;
 
 use 5.008002;
 
-our $VERSION = '1.0.0.7';
+our $VERSION = '1.0.0.2';
 
 use constant PI => 4 * atan2(1, 1);
 
@@ -27,7 +27,7 @@ sub new{
         $self->_setCurPage(1);
         
     }
-
+    
     $self->_setPDF($PDF);
     $self->setFilePath($filePath); # for retrieval when we'll want its content
                
@@ -324,12 +324,12 @@ sub drawRectangle{
     $gfx->rectxy(-(($x2-$x1)/2),-(($y2-$y1)/2),($x2-$x1)/2,($y2-$y1)/2);
     
     if ($fillcolor){
-        $gfx->fillstroke;
+        $gfx->fillstroke;    
     }
     else{
         $gfx->stroke;
     }
-
+    
     $self->_resetTransformation($gfx,($x1+$x2)/2,($y1+$y2)/2);
 }
 
@@ -541,24 +541,24 @@ sub _getImageObject{
     my ($self,$imagePath,$ext) = @_;   
     
     my $PDF = $self->getPDF;
-    if ($ext && $ext eq 'tiff'){
+    if ($ext eq 'tiff'){
         return $PDF->image_tiff($imagePath);
     }
-    elsif ($ext && $ext eq 'jpg' || $ext eq 'jpeg'){
+    elsif ($ext eq 'jpg' || $ext eq 'jpeg'){
         return $PDF->image_jpeg($imagePath);
     }
-    elsif ($ext && $ext eq 'png'){
+    elsif ($ext eq 'png'){
         return $PDF->image_png($imagePath);
     }
-    elsif ($ext && $ext eq 'pnm'){
+    elsif ($ext eq 'pnm'){
         return $PDF->image_pnm($imagePath);
     }
-    elsif ($ext && $ext eq 'gif'){
+    elsif ($ext eq 'gif'){
         return $PDF->image_gif($imagePath);
     }
     else
     {
-        return $PDF->image_gd($imagePath, -lossless => 1) ;
+        return $PDF->image_gd($imagePath) ;
     }
 }
 
@@ -584,23 +584,20 @@ sub drawText{
     my $page    = $self->_getPage($pageNo);
     my $gfx     = $page->gfx;
     
-#     $self->_applyTransformation($gfx,$x,$y);
-#     $gfx->fillcolor($color);
-#     $gfx->font($fontObj,$fontSize);
-    my $rotation = $self->_getRotation || 0 ;
+    $self->_applyTransformation($gfx,$x,$y);
+    $gfx->fillcolor($color);
+    $gfx->font($fontObj,$fontSize);
+    
     if ($align == 1){
-#         $gfx->text_center($text); # centered
-        $gfx->textlabel($x,$y,$fontObj,$fontSize,$text,-color=>$color,-center=>1, -rotate=> $rotation);
+        $gfx->text_center($text); # centered
     }
     elsif($align == 2){
-#         $gfx->text_right($text);  #right aligned
-        $gfx->textlabel($x,$y,$fontObj,$fontSize,$text,-color=>$color,-right=>1, -rotate=> $rotation);
+        $gfx->text_right($text);  #right aligned
     }
     else{
-#         $gfx->text($text); # left aligned
-        $gfx->textlabel($x,$y,$fontObj,$fontSize,$text,-color=>$color, -rotate=> $rotation);
+        $gfx->text($text); # left aligned
     }
-#     $self->_resetTransformation($gfx,$x,$y);
+    $self->_resetTransformation($gfx,$x,$y);
  
 }
 
